==> gnu-crypto-2.0.1.zip: gnu-crypto-2.0.1/source/gnu/crypto/keyring/CertPathEntry.java <==
package gnu.crypto.keyring;  // -*- c-basic-offset: 3 -*-

// ---------------------------------------------------------------------------
// $Id: CertPathEntry.java,v 1.4 2003/10/22 13:27:13 rsdio Exp $
//
// Copyright (C) 2003 Free Software Foundation, Inc.
//
// This file is part of GNU Crypto.
//
// GNU Crypto is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// GNU Crypto is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to the
//
//    Free Software Foundation Inc.,
//    59 Temple Place - Suite 330,
//    Boston, MA 02111-1307
//    USA
//
// Linking this library statically or dynamically with other modules is
// making a combined work based on this library.  Thus, the terms and
// conditions of the GNU General Public License cover the whole
// combination.
//
// As a special exception, the copyright holders of this library give
// you permission to link this library with independent modules to
// produce an executable, regardless of the license terms of these
// independent modules, and to copy and distribute the resulting
// executable under terms of your choice, provided that you also meet,
// for each linked independent module, the terms and conditions of the
// license of that module.  An independent module is a module which is
// not derived from or based on this library.  If you modify this
// library, you may extend this exception to your version of the
// library, but you are not obligated to do so.  If you do not wish to
// do so, delete this exception statement from your version.
//
// ---------------------------------------------------------------------------

import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;

import java.util.Date;

/**
 * A primitive entry that contains a path of X.509 certificates.
 */
public final class CertPathEntry extends PrimitiveEntry {

   // Constants and fields.
   // ------------------------------------------------------------------------

   public static final int TYPE = 8;

   private Certificate[] path;

   // Constructor.
   // ------------------------------------------------------------------------

   public CertPathEntry(Certificate[] path, Date creationDate,
                        Properties properties)
   {
      super(TYPE, creationDate, properties);
      if (path == null || path.length == 0) {
         throw new IllegalArgumentException("no certificate path");
      }
      this.path = (Certificate[]) path.clone();
   }

   private CertPathEntry() { }

   // Class method.
   // ------------------------------------------------------------------------

   public static CertPathEntry decode(DataInputStream in) throws IOException {
      CertPathEntry entry = new CertPathEntry();
      entry.properties = new Properties();
      entry.properties.decode(in);
      entry.makeCreationDate();
      int len = in.readInt();
      MeteredInputStream in2 = new MeteredInputStream(in, len);
      try {
         CertificateFactory fact = CertificateFactory.getInstance("X.509");
         entry.path = (Certificate[]) fact.generateCertificates(in2).toArray(new Certificate[0]);
      } catch (CertificateException ce) {
         throw new MalformedKeyringException(ce.toString());
      }
      return entry;
   }

   // Instance methods.
   // ------------------------------------------------------------------------

   public Certificate[] getCertPath() {
      return path;
   }

   protected void encodePayload() throws IOException {
      ByteArrayOutputStream bout = new ByteArrayOutputStream(1024);
      byte[] enc = null;
      try {
         for (int i = 0; i < path.length; i++) {
            bout.write(path[i].getEncoded());
         }
      } catch (CertificateEncodingException cee) {
         throw new IOException(cee.toString());
      }
      payload = bout.toByteArray();
   }
}

==> gnu-crypto-2.1.0.zip: gnu-crypto-2.1.0/source/gnu/crypto/keyring/CertPathEntry.java <==
package gnu.crypto.keyring;  // -*- c-basic-offset: 3 -*-

// ---------------------------------------------------------------------------
// $Id: CertPathEntry.java,v 1.6 2005/10/06 04:24:16 rsdio Exp $
//
// Copyright (C) 2003 Free Software Foundation, Inc.
//
// This file is part of GNU Crypto.
//
// GNU Crypto is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// GNU Crypto is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to the
//
//    Free Software Foundation Inc.,
//    51 Franklin Street, Fifth Floor,
//    Boston, MA 02110-1301
//    USA
//
// Linking this library statically or dynamically with other modules is
// making a combined work based on this library.  Thus, the terms and
// conditions of the GNU General Public License cover the whole
// combination.
//
// As a special exception, the copyright holders of this library give
// you permission to link this library with independent modules to
// produce an executable, regardless of the license terms of these
// independent modules, and to copy and distribute the resulting
// executable under terms of your choice, provided that you also meet,
// for each linked independent module, the terms and conditions of the
// license of that module.  An independent module is a module which is
// not derived from or based on this library.  If you modify this
// library, you may extend this exception to your version of the
// library, but you are not obligated to do so.  If you do not wish to
// do so, delete this exception statement from your version.
//
// ---------------------------------------------------------------------------

import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;

import java.util.Date;

/**
 * A primitive entry that contains a path of X.509 certificates.
 */
public final class CertPathEntry extends PrimitiveEntry {

   // Constants and fields.
   // ------------------------------------------------------------------------

   public static final int TYPE = 8;

   private Certificate[] path;

   // Constructor.
   // ------------------------------------------------------------------------

   public CertPathEntry(Certificate[] path, Date creationDate,
                        Properties properties)
   {
      super(TYPE, creationDate, properties);
      if (path == null || path.length == 0) {
         throw new IllegalArgumentException("no certificate path");
      }
      this.path = (Certificate[]) path.clone();
   }

   private CertPathEntry() {
      super (TYPE);
   }

   // Class method.
   // ------------------------------------------------------------------------

   public static CertPathEntry decode(DataInputStream in) throws IOException {
      CertPathEntry entry = new CertPathEntry();
      entry.properties.decode(in);
      entry.makeCreationDate();
      int len = in.readInt();
      MeteredInputStream in2 = new MeteredInputStream(in, len);
      try {
         CertificateFactory fact = CertificateFactory.getInstance("X.509");
         entry.path = (Certificate[]) fact.generateCertificates(in2).toArray(new Certificate[0]);
      } catch (CertificateException ce) {
         throw new MalformedKeyringException(ce.toString());
      }
      return entry;
   }

   // Instance methods.
   // ------------------------------------------------------------------------

   public Certificate[] getCertPath() {
      return path;
   }

   protected void encodePayload() throws IOException {
      ByteArrayOutputStream bout = new ByteArrayOutputStream(1024);
      byte[] enc = null;
      try {
         for (int i = 0; i < path.length; i++) {
            bout.write(path[i].getEncoded());
         }
      } catch (CertificateEncodingException cee) {
         throw new IOException(cee.toString());
      }
      payload = bout.toByteArray();
   }
}
